@@ -56,19 +56,20 @@ class MetastoreWriter:
         logger.info(f"Writing table {table_name} started")
 
         target_table = get_metastore_table(table_name, self.config)
+        target_path = os.path.join(
+            target_table.path,
+            f"{target_table.info_date_settings.column}={self.info_date}",
+        )
+        df = df.drop(target_table.info_date_settings.column)
+        df_writer = (
+            # TODO #24 calculate and make repartition instead
+            df.write.option(
+                "maxRecordsPerFile",
+                target_table.records_per_partition,
+            )
+        )
         if target_table.format is TableFormat.parquet:
-            target_path = os.path.join(
-                target_table.path,
-                f"{target_table.info_date_settings.column}={self.info_date}",
-            )
-            (
-                df.drop(target_table.info_date_settings.column)
-                # TODO #24 calculate and make repartition instead
-                .write.option(
-                    "maxRecordsPerFile",
-                    target_table.records_per_partition,
-                ).parquet(target_path, mode="overwrite")
-            )
+            df_writer.parquet(target_path, mode="overwrite")
         elif target_table.format is TableFormat.delta:
             raise NotImplementedError
         else:
